from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_SETTLEMENT_ENCHASHMENT



class V2TradeSettlementEnchashmentRequest(object):
    """
    取现接口
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 取现金额
    cash_amt = ""
    # 取现方ID号
    huifu_id = ""
    # 到账日期类型
    into_acct_date_type = ""
    # 取现卡序列号
    token_no = ""

    def post(self, extend_infos):
        """
        取现接口

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "cash_amt":self.cash_amt,
            "huifu_id":self.huifu_id,
            "into_acct_date_type":self.into_acct_date_type,
            "token_no":self.token_no
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_SETTLEMENT_ENCHASHMENT, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_SETTLEMENT_SURROGATE



class V2TradeSettlementSurrogateRequest(object):
    """
    银行卡代发
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户号
    huifu_id = ""
    # 代发金额
    cash_amt = ""
    # 代发用途描述
    purpose_desc = ""
    # 省份选填，参见[代发省市地区码](https://cloudpnrcdn.oss-cn-shanghai.aliyuncs.com/opps/api/prod/download_file/area/%E6%96%97%E6%8B%B1%E4%BB%A3%E5%8F%91%E7%9C%81%E4%BB%BD%E5%9C%B0%E5%8C%BA%E7%BC%96%E7%A0%81.xlsx)；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：0013&lt;/font&gt;&lt;br/&gt;对公代发(省份+地区)与联行号信息二选一填入；对私代发非必填；
    province = ""
    # 地区选填，参见[代发省市地区码](https://cloudpnrcdn.oss-cn-shanghai.aliyuncs.com/opps/api/prod/download_file/area/%E6%96%97%E6%8B%B1%E4%BB%A3%E5%8F%91%E7%9C%81%E4%BB%BD%E5%9C%B0%E5%8C%BA%E7%BC%96%E7%A0%81.xlsx)；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：1301&lt;/font&gt;&lt;br/&gt;对公代发(省份+地区)与联行号信息二选一填入；对私代发非必填；
    area = ""
    # 银行编号
    bank_code = ""
    # 联行号选填，参见：[银行支行编码](https://paas.huifu.com/partners/api/#/csfl/api_csfl_yhzhbm) &lt;font color&#x3D;&quot;green&quot;&gt;示例值：102290026507&lt;/font&gt;&lt;br/&gt;对公代发(省份+地区)与联行号信息二选一填入；对私代发非必填；
    correspondent_code = ""
    # 银行卡用户名
    bank_account_name = ""
    # 对公对私标识
    card_acct_type = ""
    # 银行账号密文
    bank_card_no_crypt = ""
    # 证件号密文
    certificate_no_crypt = ""
    # 证件类型
    certificate_type = ""
    # 手机号密文
    mobile_no_crypt = ""
    # 到账日期类型
    into_acct_date_type = ""

    def post(self, extend_infos):
        """
        银行卡代发

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "cash_amt":self.cash_amt,
            "purpose_desc":self.purpose_desc,
            "province":self.province,
            "area":self.area,
            "bank_code":self.bank_code,
            "correspondent_code":self.correspondent_code,
            "bank_account_name":self.bank_account_name,
            "card_acct_type":self.card_acct_type,
            "bank_card_no_crypt":self.bank_card_no_crypt,
            "certificate_no_crypt":self.certificate_no_crypt,
            "certificate_type":self.certificate_type,
            "mobile_no_crypt":self.mobile_no_crypt,
            "into_acct_date_type":self.into_acct_date_type
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_SETTLEMENT_SURROGATE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_ONLINEPAYMENT_QUERY



class V2TradeOnlinepaymentQueryRequest(object):
    """
    线上交易查询
    """

    # 商户号
    huifu_id = ""
    # 原交易请求日期
    org_req_date = ""
    # 原交易返回的全局流水号原交易请求流水号、原交易返回的全局流水号至少要送其中一项；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：00290TOP1GR210919004230P853ac13262200000&lt;/font&gt;
    org_hf_seq_id = ""
    # 原交易请求流水号原交易请求流水号、原交易返回的全局流水号至少要送其中一项；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：2021091708126665001&lt;/font&gt;
    org_req_seq_id = ""

    def post(self, extend_infos):
        """
        线上交易查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "org_req_date":self.org_req_date,
            "org_hf_seq_id":self.org_hf_seq_id,
            "org_req_seq_id":self.org_req_seq_id
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_ONLINEPAYMENT_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_BASICDATA_ENT



class V2MerchantBasicdataEntRequest(object):
    """
    企业商户基本信息入驻(2022)
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 上级主体ID
    upper_huifu_id = ""
    # 商户名称
    reg_name = ""
    # 商户简称
    short_name = ""
    # 公司类型
    ent_type = ""
    # 营业执照编号
    license_code = ""
    # 营业执照有效期类型
    license_validity_type = ""
    # 营业执照有效期开始日期
    license_begin_date = ""
    # 营业执照有效期截止日期日期格式：yyyyMMdd，以北京时间为准。&lt;font color&#x3D;&quot;green&quot;&gt;示例值：20220125&lt;/font&gt;&lt;br/&gt;  当license_validity_type&#x3D;0时必填  ;当license_validity_type&#x3D;1时为空；当使用总部资质时不填
    license_end_date = ""
    # 注册省
    reg_prov_id = ""
    # 注册市
    reg_area_id = ""
    # 注册区
    reg_district_id = ""
    # 注册详细地址
    reg_detail = ""
    # 法人姓名
    legal_name = ""
    # 法人证件类型
    legal_cert_type = ""
    # 法人证件号码
    legal_cert_no = ""
    # 法人证件有效期类型
    legal_cert_validity_type = ""
    # 法人证件有效期开始日期
    legal_cert_begin_date = ""
    # 法人证件有效期截止日期日期格式：yyyyMMdd，以北京时间为准。  &lt;font color&#x3D;&quot;green&quot;&gt;示例值：20220125&lt;/font&gt;&lt;br/&gt;当legal_cert_validity_type&#x3D;0时必填 ；当legal_cert_validity_type&#x3D;1时为空 ；当使用总部资质时不填
    legal_cert_end_date = ""
    # 经营省
    prov_id = ""
    # 经营市
    area_id = ""
    # 经营区
    district_id = ""
    # 经营详细地址
    detail_addr = ""
    # 联系人姓名
    contact_name = ""
    # 联系人手机号
    contact_mobile_no = ""
    # 联系人电子邮箱
    contact_email = ""
    # 客服电话
    service_phone = ""
    # 经营类型
    busi_type = ""
    # 小票名称
    receipt_name = ""
    # 所属行业
    mcc = ""
    # 结算卡信息配置
    card_info = ""
    # 基本存款账户编号或核准号基本存款账户信息请填写基本存款账户编号；开户许可证请填写核准号 ；&lt;br/&gt;当注册地址或经营地址为如下地区时必填：浙江,海南,重庆,河南,江苏,宁波市,黑龙江,吉林,湖南,贵州,陕西,湖北 &lt;br/&gt;当使用总部资质时不填 ；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：J2900123456789&lt;/font&gt;
    open_licence_no = ""
    # 总部汇付Id如果headOfficeFlag&#x3D;0，useHeadInfoFlag&#x3D;Y,且head_huifu_id不为空则基本信息部分复用总部的基本信息。&lt;br/&gt;如果head_office_flag&#x3D;0，则字段必填,如果head_office_flag&#x3D;1，总部汇付Id不可传&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：6666000123123123&lt;/font&gt;
    head_huifu_id = ""

    def post(self, extend_infos):
        """
        企业商户基本信息入驻(2022)

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "upper_huifu_id":self.upper_huifu_id,
            "reg_name":self.reg_name,
            "short_name":self.short_name,
            "ent_type":self.ent_type,
            "license_code":self.license_code,
            "license_validity_type":self.license_validity_type,
            "license_begin_date":self.license_begin_date,
            "license_end_date":self.license_end_date,
            "reg_prov_id":self.reg_prov_id,
            "reg_area_id":self.reg_area_id,
            "reg_district_id":self.reg_district_id,
            "reg_detail":self.reg_detail,
            "legal_name":self.legal_name,
            "legal_cert_type":self.legal_cert_type,
            "legal_cert_no":self.legal_cert_no,
            "legal_cert_validity_type":self.legal_cert_validity_type,
            "legal_cert_begin_date":self.legal_cert_begin_date,
            "legal_cert_end_date":self.legal_cert_end_date,
            "prov_id":self.prov_id,
            "area_id":self.area_id,
            "district_id":self.district_id,
            "detail_addr":self.detail_addr,
            "contact_name":self.contact_name,
            "contact_mobile_no":self.contact_mobile_no,
            "contact_email":self.contact_email,
            "service_phone":self.service_phone,
            "busi_type":self.busi_type,
            "receipt_name":self.receipt_name,
            "mcc":self.mcc,
            "card_info":self.card_info,
            "open_licence_no":self.open_licence_no,
            "head_huifu_id":self.head_huifu_id
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_BASICDATA_ENT, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_DIRECT_WECHAT_SIGN



class V2MerchantDirectWechatSignRequest(object):
    """
    微信特约商户进件
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户汇付Id
    huifu_id = ""
    # 渠道商汇付Id
    upper_huifu_id = ""
    # 开发者的应用ID
    app_id = ""
    # 商户号
    mch_id = ""
    # 经营者/法人是否为受益人
    owner = ""
    # 超级管理员信息
    contact_info = ""
    # 经营场景类型
    sales_scenes_type = ""
    # 经营场景
    sales_info = ""
    # 结算信息
    settlement_info = ""

    def post(self, extend_infos):
        """
        微信特约商户进件

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "upper_huifu_id":self.upper_huifu_id,
            "app_id":self.app_id,
            "mch_id":self.mch_id,
            "owner":self.owner,
            "contact_info":self.contact_info,
            "sales_scenes_type":self.sales_scenes_type,
            "sales_info":self.sales_info,
            "settlement_info":self.settlement_info
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_DIRECT_WECHAT_SIGN, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_SETTLEMENT_QUERY



class V2TradeSettlementQueryRequest(object):
    """
    出金交易查询接口
    """

    # 汇付客户Id
    huifu_id = ""
    # 原交易请求日期
    org_req_date = ""
    # 原交易返回的全局流水号原交易返回的全局流水号、原交易请求流水号二选一必填；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：00470topo1A211015160805P090ac132fef00000&lt;/font&gt;
    org_hf_seq_id = ""
    # 原交易请求流水号原交易返回的全局流水号、原交易请求流水号二选一必填；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：202109167745558220003&lt;/font&gt;
    org_req_seq_id = ""

    def post(self, extend_infos):
        """
        出金交易查询接口

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "org_req_date":self.org_req_date,
            "org_hf_seq_id":self.org_hf_seq_id,
            "org_req_seq_id":self.org_req_seq_id
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_SETTLEMENT_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYSCORE_SERVICEORDER_CANCEL



class V2TradePayscoreServiceorderCancelRequest(object):
    """
    取消支付分订单
    """

    # 汇付商户号
    huifu_id = ""
    # 取消服务订单原因
    reason = ""

    def post(self, extend_infos):
        """
        取消支付分订单

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "reason":self.reason
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYSCORE_SERVICEORDER_CANCEL, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYSCORE_SERVICEORDER_CREATE



class V2TradePayscoreServiceorderCreateRequest(object):
    """
    创建支付分订单
    """

    # 汇付商户号
    huifu_id = ""
    # 请求日期
    req_date = ""
    # 商户申请单号
    req_seq_id = ""
    # 服务信息
    service_introduction = ""
    # 服务风险金
    risk_fund = ""
    # 服务时间
    time_range = ""
    # 商户回调地址
    notify_url = ""

    def post(self, extend_infos):
        """
        创建支付分订单

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "service_introduction":self.service_introduction,
            "risk_fund":self.risk_fund,
            "time_range":self.time_range,
            "notify_url":self.notify_url
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYSCORE_SERVICEORDER_CREATE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_COMPLAINT_REPLY



class V2MerchantComplaintReplyRequest(object):
    """
    回复用户
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 微信投诉单号
    complaint_id = ""
    # 被诉商户微信号
    complainted_mchid = ""
    # 回复内容
    response_content = ""
    # 跳转链接
    jump_url = ""
    # 跳转链接文案
    jump_url_text = ""
    # 微信商户号
    mch_id = ""

    def post(self, extend_infos):
        """
        回复用户

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "complaint_id":self.complaint_id,
            "complainted_mchid":self.complainted_mchid,
            "response_content":self.response_content,
            "jump_url":self.jump_url,
            "jump_url_text":self.jump_url_text,
            "mch_id":self.mch_id
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_COMPLAINT_REPLY, required_params)



from dg_sdk.request.v2_trade_acctpayment_acctlog_query_request import V2TradeAcctpaymentAcctlogQueryRequest
from dg_sdk.request.v2_trade_acctpayment_pay_query_request import V2TradeAcctpaymentPayQueryRequest
from dg_sdk.request.v2_trade_acctpayment_refund_request import V2TradeAcctpaymentRefundRequest
from dg_sdk.request.v2_trade_acctpayment_refund_query_request import V2TradeAcctpaymentRefundQueryRequest
from dg_sdk.request.v2_trade_acctpayment_pay_request import V2TradeAcctpaymentPayRequest
from dg_sdk.request.v2_trade_cardbin_query_request import V2TradeCardbinQueryRequest
from dg_sdk.request.v2_trade_settlement_query_request import V2TradeSettlementQueryRequest
from dg_sdk.request.v2_trade_hosting_payment_preorder_h5_request import V2TradeHostingPaymentPreorderH5Request
from dg_sdk.request.v2_trade_hosting_payment_preorder_wx_request import V2TradeHostingPaymentPreorderWxRequest
from dg_sdk.request.v2_trade_hosting_payment_preorder_ali_request import V2TradeHostingPaymentPreorderAliRequest
from dg_sdk.request.v2_trade_settlement_surrogate_request import V2TradeSettlementSurrogateRequest
from dg_sdk.request.v2_quickbuckle_withhold_query_request import V2QuickbuckleWithholdQueryRequest
from dg_sdk.request.v2_quickbuckle_withhold_apply_request import V2QuickbuckleWithholdApplyRequest
from dg_sdk.request.v2_quickbuckle_withhold_page_get_request import V2QuickbuckleWithholdPageGetRequest
from dg_sdk.request.v2_trade_onlinepayment_withholdpay_request import V2TradeOnlinepaymentWithholdpayRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_account_request import V2TradeOnlinepaymentTransferAccountRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_account_close_request import V2TradeOnlinepaymentTransferAccountCloseRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_remittanceorder_request import V2TradeOnlinepaymentTransferRemittanceorderRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_remittance_request import V2TradeOnlinepaymentTransferRemittanceRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_account_query_request import V2TradeOnlinepaymentTransferAccountQueryRequest
from dg_sdk.request.v2_trade_settlement_enchashment_dmamt_query_request import V2TradeSettlementEnchashmentDmamtQueryRequest
from dg_sdk.request.v2_trade_payment_getelectronicreceipt_request import V2TradePaymentGetelectronicreceiptRequest
from dg_sdk.request.v2_trade_electron_receipts_customentrances_create_request import V2TradeElectronReceiptsCustomentrancesCreateRequest
from dg_sdk.request.v2_trade_electron_receipts_customentrances_query_request import V2TradeElectronReceiptsCustomentrancesQueryRequest
from dg_sdk.request.v2_trade_electron_receipts_upload_request import V2TradeElectronReceiptsUploadRequest
from dg_sdk.request.v2_trade_electron_receipts_picture_upload_request import V2TradeElectronReceiptsPictureUploadRequest
from dg_sdk.request.v2_trade_electron_receipts_jumpinfo_request import V2TradeElectronReceiptsJumpinfoRequest
from dg_sdk.request.v2_trade_trans_split_query_request import V2TradeTransSplitQueryRequest
from dg_sdk.request.v2_merchant_split_config_request import V2MerchantSplitConfigRequest
from dg_sdk.request.v2_merchant_split_query_request import V2MerchantSplitQueryRequest
from dg_sdk.request.v2_pcredit_solution_create_request import V2PcreditSolutionCreateRequest
from dg_sdk.request.v2_pcredit_order_query_request import V2PcreditOrderQueryRequest
from dg_sdk.request.v2_pcredit_statue_modify_request import V2PcreditStatueModifyRequest
from dg_sdk.request.v2_pcredit_solution_modify_request import V2PcreditSolutionModifyRequest
from dg_sdk.request.v2_pcredit_solution_query_request import V2PcreditSolutionQueryRequest
from dg_sdk.request.v2_pcredit_certificate_config_request import V2PcreditCertificateConfigRequest
from dg_sdk.request.v2_trade_bankinstallmentinfo_query_request import V2TradeBankinstallmentinfoQueryRequest
from dg_sdk.request.v2_pcredit_fee_config_request import V2PcreditFeeConfigRequest
from dg_sdk.request.v2_pcredit_fee_detail_request import V2PcreditFeeDetailRequest
from dg_sdk.request.v2_trade_payment_micropay_request import V2TradePaymentMicropayRequest
from dg_sdk.request.v2_trade_payment_jspay_request import V2TradePaymentJspayRequest
from dg_sdk.request.v2_merchant_basicdata_settlement_query_request import V2MerchantBasicdataSettlementQueryRequest
from dg_sdk.request.v2_trade_payment_scanpay_closequery_request import V2TradePaymentScanpayClosequeryRequest
from dg_sdk.request.v2_trade_check_replay_request import V2TradeCheckReplayRequest
from dg_sdk.request.v2_trade_check_filequery_request import V2TradeCheckFilequeryRequest
from dg_sdk.request.v2_merchant_busi_bill_config_request import V2MerchantBusiBillConfigRequest
from dg_sdk.request.v2_merchant_busi_bill_query_request import V2MerchantBusiBillQueryRequest
from dg_sdk.request.v2_trade_acctpayment_balance_query_request import V2TradeAcctpaymentBalanceQueryRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirm_request import V2TradePaymentDelaytransConfirmRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirmquery_request import V2TradePaymentDelaytransConfirmqueryRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirmrefund_request import V2TradePaymentDelaytransConfirmrefundRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirmrefundquery_request import V2TradePaymentDelaytransConfirmrefundqueryRequest
from dg_sdk.request.v2_quickbuckle_confirm_request import V2QuickbuckleConfirmRequest
from dg_sdk.request.v2_quickbuckle_apply_request import V2QuickbuckleApplyRequest
from dg_sdk.request.v2_trade_onlinepayment_quickpay_smscheck_request import V2TradeOnlinepaymentQuickpaySmscheckRequest
from dg_sdk.request.v2_quickbuckle_unbind_request import V2QuickbuckleUnbindRequest
from dg_sdk.request.v2_trade_onlinepayment_quickpay_frontpay_request import V2TradeOnlinepaymentQuickpayFrontpayRequest
from dg_sdk.request.v2_trade_onlinepayment_quickpay_confirm_request import V2TradeOnlinepaymentQuickpayConfirmRequest
from dg_sdk.request.v2_trade_onlinepayment_quickpay_apply_request import V2TradeOnlinepaymentQuickpayApplyRequest
from dg_sdk.request.v2_trade_batchtranslog_query_request import V2TradeBatchtranslogQueryRequest
from dg_sdk.request.v2_trade_transstat_query_request import V2TradeTransstatQueryRequest
from dg_sdk.request.v2_trade_payment_scanpay_query_request import V2TradePaymentScanpayQueryRequest
from dg_sdk.request.v2_trade_payment_scanpay_close_request import V2TradePaymentScanpayCloseRequest
from dg_sdk.request.v2_trade_payment_scanpay_refund_request import V2TradePaymentScanpayRefundRequest
from dg_sdk.request.v2_trade_payment_scanpay_refundquery_request import V2TradePaymentScanpayRefundqueryRequest
from dg_sdk.request.v2_trade_payment_usermark2_query_request import V2TradePaymentUsermark2QueryRequest
from dg_sdk.request.v2_trade_settlement_enchashment_request import V2TradeSettlementEnchashmentRequest
from dg_sdk.request.v2_merchant_busi_modify_busistatus_request import V2MerchantBusiModifyBusistatusRequest
from dg_sdk.request.v2_merchant_complaint_complete_request import V2MerchantComplaintCompleteRequest
from dg_sdk.request.v2_merchant_complaint_reply_request import V2MerchantComplaintReplyRequest
from dg_sdk.request.v2_merchant_complaint_update_refundprogress_request import V2MerchantComplaintUpdateRefundprogressRequest
from dg_sdk.request.v2_merchant_complaint_download_picture_request import V2MerchantComplaintDownloadPictureRequest
from dg_sdk.request.v2_merchant_complaint_list_info_query_request import V2MerchantComplaintListInfoQueryRequest
from dg_sdk.request.v2_merchant_complaint_history_query_request import V2MerchantComplaintHistoryQueryRequest
from dg_sdk.request.v2_merchant_complaint_ali_riskinfo_query_request import V2MerchantComplaintAliRiskinfoQueryRequest
from dg_sdk.request.v2_merchant_complaint_request_certificates_request import V2MerchantComplaintRequestCertificatesRequest
from dg_sdk.request.v2_merchant_complaint_query_status_request import V2MerchantComplaintQueryStatusRequest
from dg_sdk.request.v2_merchant_complaint_submit_certificates_request import V2MerchantComplaintSubmitCertificatesRequest
from dg_sdk.request.v2_merchant_busi_at_modify_request import V2MerchantBusiAtModifyRequest
from dg_sdk.request.v2_merchant_busi_mercode_query_request import V2MerchantBusiMercodeQueryRequest
from dg_sdk.request.v2_merchant_basicdata_indv_request import V2MerchantBasicdataIndvRequest
from dg_sdk.request.v2_merchant_basicdata_ent_request import V2MerchantBasicdataEntRequest
from dg_sdk.request.v2_merchant_basicdata_sms_send_request import V2MerchantBasicdataSmsSendRequest
from dg_sdk.request.v2_merchant_activity_add_request import V2MerchantActivityAddRequest
from dg_sdk.request.v2_merchant_activity_query_request import V2MerchantActivityQueryRequest
from dg_sdk.request.v2_merchant_basicdata_modify_request import V2MerchantBasicdataModifyRequest
from dg_sdk.request.v2_supplementary_picture_request import V2SupplementaryPictureRequest
from dg_sdk.request.v2_merchant_integrate_update_request import V2MerchantIntegrateUpdateRequest
from dg_sdk.request.v2_merchant_integrate_reg_request import V2MerchantIntegrateRegRequest
from dg_sdk.request.v2_merchant_url_forward_request import V2MerchantUrlForwardRequest
from dg_sdk.request.v2_merchant_busi_status_query_request import V2MerchantBusiStatusQueryRequest
from dg_sdk.request.v2_merchant_basicdata_query_request import V2MerchantBasicdataQueryRequest
from dg_sdk.request.v2_merchant_busi_open_request import V2MerchantBusiOpenRequest
from dg_sdk.request.v2_merchant_busi_modify_request import V2MerchantBusiModifyRequest
from dg_sdk.request.v2_merchant_basicdata_status_query_request import V2MerchantBasicdataStatusQueryRequest
from dg_sdk.request.v2_merchant_busi_config_request import V2MerchantBusiConfigRequest
from dg_sdk.request.v2_merchant_busi_config_query_request import V2MerchantBusiConfigQueryRequest
from dg_sdk.request.v2_merchant_busi_realname_request import V2MerchantBusiRealnameRequest
from dg_sdk.request.v2_merchant_busi_realname_query_request import V2MerchantBusiRealnameQueryRequest
from dg_sdk.request.v2_quickbuckle_bank_query_request import V2QuickbuckleBankQueryRequest
from dg_sdk.request.v2_merchant_busi_ali_realname_query_request import V2MerchantBusiAliRealnameQueryRequest
from dg_sdk.request.v2_merchant_busi_ali_realname_apply_request import V2MerchantBusiAliRealnameApplyRequest
from dg_sdk.request.v2_trade_feecalc_request import V2TradeFeecalcRequest
from dg_sdk.request.v2_trade_onlinepayment_unionpay_request import V2TradeOnlinepaymentUnionpayRequest
from dg_sdk.request.v2_trade_wxusermark_query_request import V2TradeWxusermarkQueryRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_create_request import V2TradePayscoreServiceorderCreateRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_query_request import V2TradePayscoreServiceorderQueryRequest
from dg_sdk.request.v2_trade_payscore_deduct_query_request import V2TradePayscoreDeductQueryRequest
from dg_sdk.request.v2_trade_payscore_deduct_regitster_request import V2TradePayscoreDeductRegitsterRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_cancel_request import V2TradePayscoreServiceorderCancelRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_complete_request import V2TradePayscoreServiceorderCompleteRequest
from dg_sdk.request.v2_trade_payscore_pay_payscorepay_request import V2TradePayscorePayPayscorepayRequest
from dg_sdk.request.v2_merchant_direct_wechat_settlementinfo_query_request import V2MerchantDirectWechatSettlementinfoQueryRequest
from dg_sdk.request.v2_merchant_direct_wechat_query_request import V2MerchantDirectWechatQueryRequest
from dg_sdk.request.v2_merchant_direct_wechat_subscribe_config_request import V2MerchantDirectWechatSubscribeConfigRequest
from dg_sdk.request.v2_merchant_direct_wechat_subscribe_query_request import V2MerchantDirectWechatSubscribeQueryRequest
from dg_sdk.request.v2_merchant_direct_wechat_sign_request import V2MerchantDirectWechatSignRequest
from dg_sdk.request.v2_merchant_direct_wechat_settlementinfo_modify_request import V2MerchantDirectWechatSettlementinfoModifyRequest
from dg_sdk.request.v2_merchant_direct_certinfo_add_request import V2MerchantDirectCertinfoAddRequest
from dg_sdk.request.v2_trade_onlinepayment_bankpay_payerquery_request import V2TradeOnlinepaymentBankpayPayerqueryRequest
from dg_sdk.request.v2_trade_onlinepayment_wappay_request import V2TradeOnlinepaymentWappayRequest
from dg_sdk.request.v2_trade_onlinepayment_bankpay_banklist_request import V2TradeOnlinepaymentBankpayBanklistRequest
from dg_sdk.request.v2_trade_onlinepayment_banking_frontpay_request import V2TradeOnlinepaymentBankingFrontpayRequest
from dg_sdk.request.v2_trade_onlinepayment_query_request import V2TradeOnlinepaymentQueryRequest
from dg_sdk.request.v2_trade_onlinepayment_refund_request import V2TradeOnlinepaymentRefundRequest
from dg_sdk.request.v2_trade_onlinepayment_refund_query_request import V2TradeOnlinepaymentRefundQueryRequest
from dg_sdk.request.v2_user_basicdata_indv_modify_request import V2UserBasicdataIndvModifyRequest
from dg_sdk.request.v2_user_basicdata_indv_request import V2UserBasicdataIndvRequest
from dg_sdk.request.v2_user_basicdata_ent_modify_request import V2UserBasicdataEntModifyRequest
from dg_sdk.request.v2_user_basicdata_ent_request import V2UserBasicdataEntRequest
from dg_sdk.request.v2_user_basicdata_query_request import V2UserBasicdataQueryRequest
from dg_sdk.request.v2_user_busi_open_request import V2UserBusiOpenRequest
from dg_sdk.request.v2_user_busi_modify_request import V2UserBusiModifyRequest
from dg_sdk.request.v2_quickbuckle_onekey_cardbind_request import V2QuickbuckleOnekeyCardbindRequest
from dg_sdk.request.v2_trade_preauth_request import V2TradePreauthRequest
from dg_sdk.request.v2_trade_payment_preauthcancel_refund_request import V2TradePaymentPreauthcancelRefundRequest
from dg_sdk.request.v2_trade_preauthpay_request import V2TradePreauthpayRequest
from dg_sdk.request.v2_trade_payment_preauthpaycancel_refund_request import V2TradePaymentPreauthpaycancelRefundRequest
from dg_sdk.request.v2_terminaldevice_deviceinfo_query_request import V2TerminaldeviceDeviceinfoQueryRequest
from dg_sdk.request.v2_terminaldevice_deviceinfo_add_request import V2TerminaldeviceDeviceinfoAddRequest
from dg_sdk.request.v2_terminaldevice_deviceinfo_cancel_request import V2TerminaldeviceDeviceinfoCancelRequest
from dg_sdk.request.v2_terminaldevice_manage_bind_request import V2TerminaldeviceManageBindRequest
from dg_sdk.request.v2_terminaldevice_manage_unbind_request import V2TerminaldeviceManageUnbindRequest
from dg_sdk.request.v2_terminaldevice_manage_query_request import V2TerminaldeviceManageQueryRequest
from dg_sdk.request.v2_merchant_direct_zft_receiver_config_request import V2MerchantDirectZftReceiverConfigRequest
from dg_sdk.request.v2_merchant_direct_zft_receiver_query_request import V2MerchantDirectZftReceiverQueryRequest
from dg_sdk.request.v2_merchant_direct_zft_reg_request import V2MerchantDirectZftRegRequest
from dg_sdk.request.v2_merchant_direct_alipay_applyorderstatus_query_request import V2MerchantDirectAlipayApplyorderstatusQueryRequest
from dg_sdk.request.v2_merchant_direct_alipay_appauthtoken_exchange_request import V2MerchantDirectAlipayAppauthtokenExchangeRequest
from dg_sdk.request.v2_merchant_direct_alipay_facetofacesign_apply_request import V2MerchantDirectAlipayFacetofacesignApplyRequest
from dg_sdk.request.v2_merchant_settle_modify_request import V2MerchantSettleModifyRequest
from dg_sdk.request.v2_merchant_settle_config_request import V2MerchantSettleConfigRequest



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_ONLINEPAYMENT_TRANSFER_ACCOUNT_QUERY



class V2TradeOnlinepaymentTransferAccountQueryRequest(object):
    """
    银行转账资金流水查询
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户号
    huifu_id = ""
    # 原请求流水号
    org_req_seq_id = ""
    # 原请求日期
    org_req_date = ""
    # 打款结束日期
    trans_end_date = ""
    # 交易开始日期
    trans_start_date = ""

    def post(self, extend_infos):
        """
        银行转账资金流水查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "org_req_seq_id":self.org_req_seq_id,
            "org_req_date":self.org_req_date,
            "trans_end_date":self.trans_end_date,
            "trans_start_date":self.trans_start_date
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_ONLINEPAYMENT_TRANSFER_ACCOUNT_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYMENT_SCANPAY_REFUNDQUERY



class V2TradePaymentScanpayRefundqueryRequest(object):
    """
    交易退款查询接口
    """

    # 商户号
    huifu_id = ""
    # 退款请求日期
    org_req_date = ""
    # 退款全局流水号退款请求流水号,退款全局流水号,终端订单号三选一不能都为空；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：0030default220825182711P099ac1f343f00000&lt;/font&gt;
    org_hf_seq_id = ""
    # 退款请求流水号退款请求流水号,退款全局流水号,终端订单号三选一不能都为空；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：202110210012100005&lt;/font&gt;
    org_req_seq_id = ""
    # 终端订单号退款请求流水号,退款全局流水号,终端订单号三选一不能都为空；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：16672670833524393&lt;/font&gt;
    mer_ord_id = ""

    def post(self, extend_infos):
        """
        交易退款查询接口

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "org_req_date":self.org_req_date,
            "org_hf_seq_id":self.org_hf_seq_id,
            "org_req_seq_id":self.org_req_seq_id,
            "mer_ord_id":self.mer_ord_id
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYMENT_SCANPAY_REFUNDQUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_QUICKBUCKLE_BANK_QUERY



class V2QuickbuckleBankQueryRequest(object):
    """
    银行列表查询
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 商户汇付Id
    huifu_id = ""
    # 业务类型
    biz_type = ""
    # 借贷类型
    dc_type = ""

    def post(self, extend_infos):
        """
        银行列表查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "biz_type":self.biz_type,
            "dc_type":self.dc_type
        }
        required_params.update(extend_infos)
        return request_post(V2_QUICKBUCKLE_BANK_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_DIRECT_CERTINFO_ADD



class V2MerchantDirectCertinfoAddRequest(object):
    """
    证书登记
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 渠道商汇付Id
    upper_huifu_id = ""
    # 开通类型
    pay_way = ""
    # 开发者的应用ID
    app_id = ""
    # 文件列表
    file_list = ""

    def post(self, extend_infos):
        """
        证书登记

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "upper_huifu_id":self.upper_huifu_id,
            "pay_way":self.pay_way,
            "app_id":self.app_id,
            "file_list":self.file_list
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_DIRECT_CERTINFO_ADD, required_params)



import json
import requests
from dg_sdk.core.log_util import log_error, log_info
from dg_sdk.core.param_handler import pop_empty_value, sort_dict
from dg_sdk.core.rsa_utils import rsa_sign, rsa_design
from requests.adapters import HTTPAdapter
from requests.packages.urllib3.util.retry import Retry


class ApiRequest:
    """
    网络请求类
    """
    request_url = ''
    product_id = ''
    sys_id = ''
    request_params = {}
    version = ''
    sdk_version = ''
    private_key = ''
    public_key = ''
    connect_timeout = ''
    need_sign = True
    need_verfy_sign = True

    @staticmethod
    def build(product_id, sys_id, private_key, public_key, request_url, request_params, sdk_version, need_sign,
              need_verfy_sign, connect_timeout=15):
        """
        初始化 网络请求类
        :param product_id: 产品号
        :param sys_id: 系统号
        :param private_key: 私钥
        :param public_key: 公钥
        :param request_url: 请求地址
        :param sdk_version: sdk_version
        :param need_sign: 是否需要签名
        :param need_verfy_sign: 是否需要验签
        :param request_params: 请求参数
        :param connect_timeout: 超时时间
        :return: 网络请求类
        """
        ApiRequest.product_id = product_id
        ApiRequest.sys_id = sys_id
        ApiRequest.request_url = request_url
        ApiRequest.private_key = private_key
        ApiRequest.public_key = public_key
        ApiRequest.sdk_version = sdk_version
        ApiRequest.request_params = request_params
        ApiRequest.need_sign = need_sign
        ApiRequest.need_verfy_sign = need_verfy_sign
        ApiRequest.connect_timeout = connect_timeout

    @staticmethod
    def post(request_file=None):
        return ApiRequest._request('post', request_file)

    @staticmethod
    def get():
        return ApiRequest._request('get', )

    @staticmethod
    def _build_request_info(url, params, files):
        """
        根据请求方式构造请求头和请求参数
        :param url: 请求地址
        :param params: 请求参数
        :param files: 请求文件
        :return: header 请求头 params 请求参数
        """

        # 获取商户密钥
        if not ApiRequest.private_key:
            raise RuntimeError('privite_key is none')
        # 构造请求头
        header = {"Content-Type": "application/json;charset=utf-8",
                  "sdk_version": "python_" + ApiRequest.sdk_version}
        if files:
            header = {
                "sdk_version": "python_" + ApiRequest.sdk_version}

        # 构造请求体
        body = dict()
        body["sys_id"] = ApiRequest.sys_id
        body["product_id"] = ApiRequest.product_id

        datastr = ""

        if params is not None:
            params = pop_empty_value(params)
            params = sort_dict(params=params)
            datastr = json.dumps(params, ensure_ascii=False, separators=(',', ':'))

        # 对请求参数进行加签
        sign = ''
        if ApiRequest.need_sign:
            flag, sign = rsa_sign(ApiRequest.private_key, datastr)
            if not flag:
                log_error('request to {}, sign error {} '.format(url, rsa_sign))

        # 将签名更新到请求头中
        body['sign'] = sign
        body['data'] = params

        return header, body

    @staticmethod
    def _request(method, files=None):
        """
        执行请求
        :param method: 请求方法类型

        :param files: 上传的文件
        :return: 网路请求返回的数据
        """

        request_url = ApiRequest.request_url

        header, params = ApiRequest._build_request_info(request_url, ApiRequest.request_params, files)
        log_info('request_params{} '.format(params))
        session = requests.Session()
        retry = Retry(connect=3, backoff_factor=0.5)
        adapter = HTTPAdapter(max_retries=retry)
        session.mount('http://', adapter)
        session.mount('https://', adapter)

        if files:
            params["data"] = json.dumps(params["data"])
            resp = session.post(request_url, data=params, files=files, timeout=ApiRequest.connect_timeout,
                                headers=header)
        elif method == 'post':
            resp = session.post(request_url, json=params, files=files, timeout=ApiRequest.connect_timeout,
                                headers=header)
        else:
            resp = session.get(request_url, params, timeout=ApiRequest.connect_timeout, headers=header)
        log_info(
            'request to {}\nheader={}\nrequest_params{} \nresp is {}'.format(request_url, header, params, resp.text))
        resp.close()
        return ApiRequest._build_return_data(resp)

    @staticmethod
    def _build_return_data(resp):
        """
        解析网络返回
        :param resp: response
        :return: 解析处理后的网络返回
        """
        if resp.status_code != 200:
            log_error('status_code is ' + str(resp.status_code))
            return resp
        try:
            resp_json = json.loads(resp.text)
        except Exception as e:
            log_error('status_code is ' + str(resp.status_code))
            log_error(str(e))
            return resp.text
        # 服务端返回数据
        # 当业务请求成功时验证返回数据与签名
        data = resp_json.get('data', '')
        # 返回字段中的签名
        resp_sign = resp_json.get('sign', '')
        # 如果没有签名字段，直接返回内容，一般为404等
        if not resp_sign:
            return resp_json
        if ApiRequest.need_verfy_sign:
            if not ApiRequest.public_key:
                raise RuntimeError('public_key is none')
            # 验证返回数据与返回加签结果是否一致
            flag, info = verify_sign(resp_sign, data, ApiRequest.public_key)
            if not flag:
                # 如果验签失败，抛出异常
                log_error('check signature error !'.format(info))
                raise RuntimeError(info)
        return data


def verify_sign(sign, data, public_key):
    data = sort_dict(params=data)
    data_str = json.dumps(data, ensure_ascii=False, separators=(',', ':'))
    return rsa_design(sign, data_str, public_key)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_USER_BASICDATA_INDV



class V2UserBasicdataIndvRequest(object):
    """
    个人用户基本信息开户
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 个人姓名
    name = ""
    # 个人证件类型
    cert_type = ""
    # 个人证件号码
    cert_no = ""
    # 个人证件有效期类型
    cert_validity_type = ""
    # 个人证件有效期开始日期
    cert_begin_date = ""
    # 手机号
    mobile_no = ""

    def post(self, extend_infos):
        """
        个人用户基本信息开户

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "name":self.name,
            "cert_type":self.cert_type,
            "cert_no":self.cert_no,
            "cert_validity_type":self.cert_validity_type,
            "cert_begin_date":self.cert_begin_date,
            "mobile_no":self.mobile_no
        }
        required_params.update(extend_infos)
        return request_post(V2_USER_BASICDATA_INDV, required_params)



import json

import requests

from dg_sdk.core.log_util import log_error, log_info
from dg_sdk.core.param_handler import replace_none_to_empty
from dg_sdk.core.rsa_utils import rsa_sign, rsa_design


class ApiRequest:
    """
    网络请求类
    """
    request_url = ''
    product_id = ''
    sys_id = ''
    request_params = {}
    version = ''
    sdk_version = ''
    private_key = ''
    public_key = ''
    connect_timeout = ''

    @staticmethod
    def build(product_id, sys_id, private_key, public_key, request_url, request_params, sdk_version,
              connect_timeout=30):
        """
        初始化 网络请求类
        :param product_id: 产品号
        :param sys_id: 系统号
        :param private_key: 私钥
        :param public_key: 公钥
        :param request_url: 请求地址
        :param sdk_version: sdk_version
        :param request_params: 请求参数
        :param connect_timeout: 超时时间
        :return: 网络请求类
        """
        ApiRequest.product_id = product_id
        ApiRequest.request_url = request_url
        ApiRequest.sys_id = sys_id
        ApiRequest.private_key = private_key
        ApiRequest.public_key = public_key
        ApiRequest.request_params = request_params
        ApiRequest.version = "1.0.0"
        ApiRequest.sdk_version = sdk_version
        ApiRequest.connect_timeout = connect_timeout

    @staticmethod
    def post(request_file=None):
        return ApiRequest._request('post', request_file)

    @staticmethod
    def get():
        return ApiRequest._request('get')

    @staticmethod
    def _build_request_info(url, method, params, files):
        """
        根据请求方式构造请求头和请求参数
        :param url: 请求地址
        :param method: 请求方法，post or get
        :param params: 请求参数
        :param files: 请求文件
        :return: header 请求头 params 请求参数
        """

        # 构造请求头
        header = {'product_id': ApiRequest.product_id,
                  'format': 'JSON',
                  'charset': 'UTF-8',
                  'sdk_version': 'python_' + ApiRequest.sdk_version,
                  'version': ApiRequest.version
                  }

        # 构造请求体

        body = dict()
        body["sys_id"] = ApiRequest.sys_id
        body["sign_type"] = "RSA2"

        datastr = ""

        if params is not None:
            params = replace_none_to_empty(params)
            datastr = json.dumps(params)

        # 获取商户密钥
        if not ApiRequest.private_key:
            raise RuntimeError('privite_key is none')

        # 对请求参数进行加签
        flag, sign = rsa_sign(ApiRequest.private_key, datastr, 'utf-8')

        if not flag:
            log_error('request to {}, sign error {} '.format(url, rsa_sign))

        # 将签名更新到请求头中
        body['sign'] = sign
        body['data'] = datastr

        return header, body

    @staticmethod
    def _request(method, files=None):
        """
        执行请求
        :param method: 请求方法类型

        :param files: 上传的文件
        :return: 网路请求返回的数据
        """

        request_url = ApiRequest.request_url
        header, params = ApiRequest._build_request_info(request_url, method, ApiRequest.request_params, files)

        http_method = getattr(requests, method or 'post')

        log_info('request_params{} '.format(params))

        if files:
            resp = http_method(request_url, data=params, files=files, timeout=ApiRequest.connect_timeout,
                               headers=header)
        elif method == 'post':
            resp = http_method(request_url, json=params, files=files, timeout=ApiRequest.connect_timeout,
                               headers=header)
        else:
            resp = http_method(request_url, params, timeout=ApiRequest.connect_timeout, headers=header)
        log_info(
            'request to {}\nheader={}\nrequest_params{} \nresp is {}'.format(request_url, header, params, resp.text))
        return ApiRequest._build_return_data(resp)

    @staticmethod
    def _build_return_data(resp):
        """
        解析网络返回
        :param resp: response
        :return: 解析处理后的网络返回
        """

        try:
            resp_json = json.loads(resp.text)
        except Exception as e:
            log_error('status_code is ' + str(resp.status_code))
            log_error(str(e))
            return resp.text

        # 服务端返回数据
        data = resp_json.get('data', '')
        # 返回字段中的签名
        resp_sign = resp_json.get('sign', '')
        if not resp_sign:
            # 如果没有签名字段，直接返回内容，一般为404等
            return resp_json

        # 当业务请求成功时验证返回数据与签名
        if not ApiRequest.public_key:
            raise RuntimeError('public_key is none')

        # 验证返回数据与返回加签结果是否一致
        flag, info = rsa_design(resp_sign, data, ApiRequest.public_key)

        if not flag:
            # 如果验签失败，抛出异常
            log_error('check signature error !'.format(info))
            raise RuntimeError(info)

        return json.loads(data)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_COMPLAINT_QUERY_STATUS



class V2MerchantComplaintQueryStatusRequest(object):
    """
    支付宝申诉查询
    """

    # 请求汇付流水号
    req_seq_id = ""
    # 请求汇付时间
    req_date = ""
    # 支付宝推送流水号
    risk_biz_id = ""
    # 申诉的商户
    bank_mer_code = ""

    def post(self, extend_infos):
        """
        支付宝申诉查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "risk_biz_id":self.risk_biz_id,
            "bank_mer_code":self.bank_mer_code
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_COMPLAINT_QUERY_STATUS, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_INTEGRATE_REG



class V2MerchantIntegrateRegRequest(object):
    """
    商户统一进件接口(2022)
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 渠道商汇付id
    upper_huifu_id = ""
    # 公司类型
    ent_type = ""
    # 商户名称
    reg_name = ""
    # 经营类型
    busi_type = ""
    # 经营详细地址
    detail_addr = ""
    # 经营省
    prov_id = ""
    # 经营市
    area_id = ""
    # 经营区
    district_id = ""
    # 联系人信息
    contact_info = ""
    # 卡信息配置实体
    card_info = ""
    # 取现配置列表jsonArray格式 ；
    cash_config = ""
    # 结算配置jsonObject格式；
    settle_config = ""

    def post(self, extend_infos):
        """
        商户统一进件接口(2022)

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "upper_huifu_id":self.upper_huifu_id,
            "ent_type":self.ent_type,
            "reg_name":self.reg_name,
            "busi_type":self.busi_type,
            "detail_addr":self.detail_addr,
            "prov_id":self.prov_id,
            "area_id":self.area_id,
            "district_id":self.district_id,
            "contact_info":self.contact_info,
            "card_info":self.card_info,
            "cash_config":self.cash_config,
            "settle_config":self.settle_config
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_INTEGRATE_REG, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_HOSTING_PAYMENT_PREORDER



class V2TradeHostingPaymentPreorderAliRequest(object):
    """
    支付宝小程序预下单接口
    """

    # 商户号
    huifu_id = ""
    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 预下单类型
    pre_order_type = ""
    # 交易金额
    trans_amt = ""
    # 商品描述
    goods_desc = ""
    # app扩展参数集合
    app_data = ""

    def post(self, extend_infos):
        """
        支付宝小程序预下单接口

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "pre_order_type":self.pre_order_type,
            "trans_amt":self.trans_amt,
            "goods_desc":self.goods_desc,
            "app_data":self.app_data
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_HOSTING_PAYMENT_PREORDER, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_DIRECT_ZFT_RECEIVER_CONFIG



class V2MerchantDirectZftReceiverConfigRequest(object):
    """
    直付通分账关系绑定解绑
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 汇付ID
    huifu_id = ""
    # 开发者的应用ID
    app_id = ""
    # 分账开关
    split_flag = ""
    # 分账接收方列表
    zft_split_receiver_list = ""
    # 状态
    status = ""

    def post(self, extend_infos):
        """
        直付通分账关系绑定解绑

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "app_id":self.app_id,
            "split_flag":self.split_flag,
            "zft_split_receiver_list":self.zft_split_receiver_list,
            "status":self.status
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_DIRECT_ZFT_RECEIVER_CONFIG, required_params)



# -*- coding: utf-8 -*-
import base64
from Crypto.Cipher import PKCS1_v1_5 as Cipher_pkcs1_v1_5  # 加密解密模块
from Crypto.Hash import SHA256
from Crypto.PublicKey import RSA
from Crypto.Signature import pkcs1_15  # 加签验签模块


#  公钥加密，单次加密串的长度最大为(key_size/8 - 11)，本次以2048为例
# 公钥加密
def rsa_long_encrypt(message, my_rsa_public):
    try:
        if not message:
            return ""
        msg = message.encode('utf-8')  # 待加密信息转成utf-8形式
        length = len(msg)
        default_length = 245
        my_rsa_public = add_start_end(my_rsa_public, "-----BEGIN PUBLIC KEY-----\n", "\n-----END PUBLIC KEY-----")

        pubobj = Cipher_pkcs1_v1_5.new(RSA.importKey(my_rsa_public))
        # 长度不用分段
        if length < default_length:
            return base64.b64encode(pubobj.encrypt(msg)).decode("utf-8")
        # 需要分段
        offset = 0
        res = []
        while length - offset > 0:
            if length - offset > default_length:
                res.append(pubobj.encrypt(msg[offset:offset + default_length]))
            else:
                res.append(pubobj.encrypt(msg[offset:]))
            offset += default_length
        byte_data = b''.join(res)
        return base64.b64encode(byte_data).decode("utf-8")  # 对返回内容以base64编码
    except Exception as ex:
        return str(ex)


# 私钥解密
def rsa_long_decrypt(message, my_rsa_private):
    try:
        msg = base64.b64decode(message)
        length = len(msg)
        default_length = 256
        # 私钥解密
        priobj = Cipher_pkcs1_v1_5.new(RSA.importKey(my_rsa_private))
        # 长度不用分段
        if length < default_length:
            return b''.join(priobj.decrypt(msg, b'xyz'))
        # 需要分段
        offset = 0
        res = []
        while length - offset > 0:
            if length - offset > default_length:
                res.append(priobj.decrypt(msg[offset:offset + default_length], b'xyz'))
            else:
                res.append(priobj.decrypt(msg[offset:], b'xyz'))
            offset += default_length
            m = b''.join(res)
            n = m.decode("utf-8")
        return n
    except Exception as ex:
        return str(ex)


# 私钥加签
def rsa_sign(private_key, message, charset='utf-8'):
    try:
        private_key = add_start_end(private_key, "-----BEGIN PRIVATE KEY-----\n", "\n-----END PRIVATE KEY-----")
        msg = message.encode(charset)
        private_key = RSA.importKey(private_key)
        # message做“哈希”处理，RSA签名这么要求的
        hash_obj = SHA256.new(msg)
        signature = pkcs1_15.new(private_key).sign(hash_obj)
        return True, base64.b64encode(signature).decode(charset)
    except Exception as ex:
        return False, str(ex)


# 公钥验签
def rsa_design(signature, message, my_rsa_public):
    try:
        my_rsa_public = fill_public_key_marker(my_rsa_public)
        message = message.encode("utf-8")
        public_key = RSA.importKey(my_rsa_public)
        # message做“哈希”处理，RSA签名这么要求的
        hash_obj = SHA256.new(message)

        pkcs1_15.new(public_key).verify(hash_obj, base64.b64decode(signature))
        return True, ''
    except (ValueError, TypeError) as ex:
        return False, str(ex)


def add_start_end(key, start_marker, end_marker):
    if key.find(start_marker) < 0:
        key = start_marker + key
    if key.find(end_marker) < 0:
        key = key + end_marker
    return key


def fill_private_key_marker(private_key):
    return add_start_end(private_key, "-----BEGIN PRIVATE KEY-----\n", "\n-----END PRIVATE KEY-----")


def fill_public_key_marker(public_key):
    return add_start_end(public_key, "-----BEGIN PUBLIC KEY-----\n", "\n-----END PUBLIC KEY-----")



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_QUICKBUCKLE_APPLY



class V2QuickbuckleApplyRequest(object):
    """
    快捷绑卡申请接口
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 汇付客户Id
    huifu_id = ""
    # 商户用户id
    out_cust_id = ""
    # 订单号
    order_id = ""
    # 订单日期
    order_date = ""
    # 银行卡号
    card_id = ""
    # 银行卡开户姓名
    card_name = ""
    # 银行卡绑定证件类型
    cert_type = ""
    # 银行卡绑定身份证
    cert_id = ""
    # 个人证件有效期类型
    cert_validity_type = ""
    # 个人证件有效期起始日
    cert_begin_date = ""
    # 个人证件有效期到期日长期有效不填；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：20420905&lt;/font&gt;
    cert_end_date = ""
    # 银行卡绑定手机号
    card_mp = ""
    # CVV2信用卡交易专用需要密文传输。&lt;br/&gt;使用汇付RSA公钥加密(加密前3位，加密后最长2048位），[参见参考文档](https://paas.huifu.com/partners/guide/#/api_jiami_jiemi)；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：Ly+fnExeyPOTzfOtgRRur77nJB9TAe4PGgK9M……fc6XJXZss&#x3D;&lt;/font&gt;
    vip_code = ""
    # 卡有效期信用卡交易专用，格式：MMYY，需要密文传输；&lt;br/&gt;使用汇付RSA公钥加密(加密前4位，加密后最长2048位），[参见参考文档](https://paas.huifu.com/partners/guide/#/api_jiami_jiemi)；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：Ly+fnExeyPOTzfOtgRRur77nJB9TAe4PGgK9M……fc6XJXZss&#x3D;JXZss&#x3D;&lt;/font&gt;
    expiration = ""
    # 挂网协议编号授权信息(招行绑卡需要上送)；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：34463343&lt;/font&gt;
    protocol_no = ""
    # 设备信息域 
    trx_device_inf = ""

    def post(self, extend_infos):
        """
        快捷绑卡申请接口

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id,
            "out_cust_id":self.out_cust_id,
            "order_id":self.order_id,
            "order_date":self.order_date,
            "card_id":self.card_id,
            "card_name":self.card_name,
            "cert_type":self.cert_type,
            "cert_id":self.cert_id,
            "cert_validity_type":self.cert_validity_type,
            "cert_begin_date":self.cert_begin_date,
            "cert_end_date":self.cert_end_date,
            "card_mp":self.card_mp,
            "vip_code":self.vip_code,
            "expiration":self.expiration,
            "protocol_no":self.protocol_no,
            "trx_device_inf":self.trx_device_inf
        }
        required_params.update(extend_infos)
        return request_post(V2_QUICKBUCKLE_APPLY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_ACTIVITY_ADD



class V2MerchantActivityAddRequest(object):
    """
    商户活动报名
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 汇付客户Id
    huifu_id = ""
    # 营业执照图片
    bl_photo = ""
    # 店内环境图片
    dh_photo = ""
    # 手续费类型
    fee_type = ""
    # 整体门面图片（门头照）
    mm_photo = ""
    # 收银台照片
    syt_photo = ""
    # 支付通道
    pay_way = ""

    def post(self, extend_infos):
        """
        商户活动报名

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id,
            "bl_photo":self.bl_photo,
            "dh_photo":self.dh_photo,
            "fee_type":self.fee_type,
            "mm_photo":self.mm_photo,
            "syt_photo":self.syt_photo,
            "pay_way":self.pay_way
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_ACTIVITY_ADD, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_TRANS_SPLIT_QUERY



class V2TradeTransSplitQueryRequest(object):
    """
    交易分账明细查询接口
    """

    # 分账交易汇付全局流水号
    hf_seq_id = ""
    # 商户号
    huifu_id = ""
    # 交易类型
    ord_type = ""

    def post(self, extend_infos):
        """
        交易分账明细查询接口

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "hf_seq_id":self.hf_seq_id,
            "huifu_id":self.huifu_id,
            "ord_type":self.ord_type
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_TRANS_SPLIT_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_BASICDATA_INDV



class V2MerchantBasicdataIndvRequest(object):
    """
    个人商户基本信息入驻(2022)
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 上级主体ID
    upper_huifu_id = ""
    # 商户名
    reg_name = ""
    # 经营省
    prov_id = ""
    # 经营市
    area_id = ""
    # 经营区
    district_id = ""
    # 经营详细地址
    detail_addr = ""
    # 联系人姓名
    contact_name = ""
    # 联系人手机号
    contact_mobile_no = ""
    # 联系人电子邮箱
    contact_email = ""
    # 结算卡信息配置
    card_info = ""

    def post(self, extend_infos):
        """
        个人商户基本信息入驻(2022)

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "upper_huifu_id":self.upper_huifu_id,
            "reg_name":self.reg_name,
            "prov_id":self.prov_id,
            "area_id":self.area_id,
            "district_id":self.district_id,
            "detail_addr":self.detail_addr,
            "contact_name":self.contact_name,
            "contact_mobile_no":self.contact_mobile_no,
            "contact_email":self.contact_email,
            "card_info":self.card_info
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_BASICDATA_INDV, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_ONLINEPAYMENT_TRANSFER_REMITTANCEORDER



class V2TradeOnlinepaymentTransferRemittanceorderRequest(object):
    """
    汇付入账查询
    """

    # 商户号
    huifu_id = ""
    # 原请求开始日期
    org_req_start_date = ""
    # 原请求结束日期
    org_req_end_date = ""

    def post(self, extend_infos):
        """
        汇付入账查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "org_req_start_date":self.org_req_start_date,
            "org_req_end_date":self.org_req_end_date
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_ONLINEPAYMENT_TRANSFER_REMITTANCEORDER, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYMENT_SCANPAY_QUERY



class V2TradePaymentScanpayQueryRequest(object):
    """
    交易查询接口
    """

    # 汇付商户号
    huifu_id = ""
    # 汇付服务订单号out_order_no,org_hf_seq_id,org_req_seq_id 必填其一；汇付生成的服务订单号；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：1234323JKHDFE1243252&lt;/font&gt;
    out_order_no = ""
    # 创建服务订单返回的汇付全局流水号out_order_no,org_hf_seq_id,org_req_seq_id 必填其一；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：00290TOP1GR210919004230P853ac13262200000&lt;/font&gt;
    org_hf_seq_id = ""
    # 服务订单创建请求流水号out_order_no,org_hf_seq_id,org_req_seq_id 必填其一；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：202110210012100005&lt;/font&gt;
    org_req_seq_id = ""
    # 原机构请求日期
    org_req_date = ""

    def post(self, extend_infos):
        """
        交易查询接口

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "out_order_no":self.out_order_no,
            "org_hf_seq_id":self.org_hf_seq_id,
            "org_req_seq_id":self.org_req_seq_id,
            "org_req_date":self.org_req_date
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYMENT_SCANPAY_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_ELECTRON_RECEIPTS_JUMPINFO



class V2TradeElectronReceiptsJumpinfoRequest(object):
    """
    跳转电子小票页面
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 商户汇付Id
    huifu_id = ""
    # 原请求日期
    org_req_date = ""
    # 原请求流水号原请求流水号、原交易返回的全局流水号至少要送其中一项；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：2021091708126665001&lt;/font&gt;
    org_req_seq_id = ""
    # 汇付全局流水号原请求流水号、原交易返回的全局流水号至少要送其中一项；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：00290TOP1GR210919004230P853ac13262200000&lt;/font&gt;
    org_hf_seq_id = ""
    # 票据信息
    receipt_data = ""

    def post(self, extend_infos):
        """
        跳转电子小票页面

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "org_req_date":self.org_req_date,
            "org_req_seq_id":self.org_req_seq_id,
            "org_hf_seq_id":self.org_hf_seq_id,
            "receipt_data":self.receipt_data
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_ELECTRON_RECEIPTS_JUMPINFO, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_CHECK_REPLAY



class V2TradeCheckReplayRequest(object):
    """
    交易结算对账文件重新生成
    """

    # 请求流水号
    req_seq_id = ""
    # 交易日期
    req_date = ""
    # 汇付机构编号
    huifu_id = ""
    # 文件类型
    file_type = ""

    def post(self, extend_infos):
        """
        交易结算对账文件重新生成

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "file_type":self.file_type
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_CHECK_REPLAY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_ELECTRON_RECEIPTS_PICTURE_UPLOAD



class V2TradeElectronReceiptsPictureUploadRequest(object):
    """
    图片上传
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户号
    huifu_id = ""
    # 三方通道类型
    third_channel_type = ""
    # 文件名称
    file_name = ""
    # 图片内容
    image_content = ""

    def post(self, extend_infos):
        """
        图片上传

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "third_channel_type":self.third_channel_type,
            "file_name":self.file_name,
            "image_content":self.image_content
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_ELECTRON_RECEIPTS_PICTURE_UPLOAD, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_DIRECT_ALIPAY_FACETOFACESIGN_APPLY



class V2MerchantDirectAlipayFacetofacesignApplyRequest(object):
    """
    支付宝直连-申请当面付代签约
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 汇付客户Id
    huifu_id = ""
    # 上级主体ID
    upper_huifu_id = ""
    # 支付宝经营类目
    direct_category = ""
    # 开发者的应用ID
    app_id = ""
    # 联系人姓名
    contact_name = ""
    # 联系人手机号
    contact_mobile_no = ""
    # 联系人电子邮箱
    contact_email = ""
    # 商户账号
    account = ""
    # 服务费率（%）0.38~3之间，精确到0.01。当签约且授权sign_and_auth&#x3D;Y时，必填。&lt;font color&#x3D;&quot;green&quot;&gt;示例值：0.38&lt;/font&gt;
    rate = ""
    # 文件列表
    file_list = ""

    def post(self, extend_infos):
        """
        支付宝直连-申请当面付代签约

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "upper_huifu_id":self.upper_huifu_id,
            "direct_category":self.direct_category,
            "app_id":self.app_id,
            "contact_name":self.contact_name,
            "contact_mobile_no":self.contact_mobile_no,
            "contact_email":self.contact_email,
            "account":self.account,
            "rate":self.rate,
            "file_list":self.file_list
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_DIRECT_ALIPAY_FACETOFACESIGN_APPLY, required_params)



import logging
from fishbase.fish_logger import logger

log_level = ''
log_tag = ''


def log_info(info):
    if logging.INFO == log_level:
        logger.info(log_tag + '{}'.format(info))


def log_warning(warning_info):
    if log_level in [logging.INFO, logging.WARNING]:
        logger.warning(log_tag + '{}'.format(warning_info))


def log_error(error_info):
    if log_level in [logging.INFO, logging.WARNING, logging.ERROR]:
        logger.error(log_tag + '{}'.format(error_info))



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_USER_BASICDATA_ENT



class V2UserBasicdataEntRequest(object):
    """
    企业用户基本信息开户
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 企业用户名称
    reg_name = ""
    # 经营简称
    short_name = ""
    # 营业执照编号
    license_code = ""
    # 证照有效期类型
    license_validity_type = ""
    # 证照有效期起始日期
    license_begin_date = ""
    # 证照有效期结束日期日期格式：yyyyMMdd; 非长期有效时必填；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：20320905&lt;/font&gt;
    license_end_date = ""
    # 注册地址(省)
    reg_prov_id = ""
    # 注册地址(市)
    reg_area_id = ""
    # 注册地址(区)
    reg_district_id = ""
    # 注册地址(详细信息)
    reg_detail = ""
    # 法人姓名
    legal_name = ""
    # 法人证件类型
    legal_cert_type = ""
    # 法人证件号码
    legal_cert_no = ""
    # 法人证件有效期类型
    legal_cert_validity_type = ""
    # 法人证件有效期开始日期
    legal_cert_begin_date = ""
    # 法人证件有效期截止日期日期格式：yyyyMMdd; 非长期有效时必填，长期有效为空；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：20320905&lt;/font&gt;
    legal_cert_end_date = ""
    # 联系人姓名
    contact_name = ""
    # 联系人手机号
    contact_mobile = ""

    def post(self, extend_infos):
        """
        企业用户基本信息开户

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "reg_name":self.reg_name,
            "short_name":self.short_name,
            "license_code":self.license_code,
            "license_validity_type":self.license_validity_type,
            "license_begin_date":self.license_begin_date,
            "license_end_date":self.license_end_date,
            "reg_prov_id":self.reg_prov_id,
            "reg_area_id":self.reg_area_id,
            "reg_district_id":self.reg_district_id,
            "reg_detail":self.reg_detail,
            "legal_name":self.legal_name,
            "legal_cert_type":self.legal_cert_type,
            "legal_cert_no":self.legal_cert_no,
            "legal_cert_validity_type":self.legal_cert_validity_type,
            "legal_cert_begin_date":self.legal_cert_begin_date,
            "legal_cert_end_date":self.legal_cert_end_date,
            "contact_name":self.contact_name,
            "contact_mobile":self.contact_mobile
        }
        required_params.update(extend_infos)
        return request_post(V2_USER_BASICDATA_ENT, required_params)
